@@ -25,17 +25,16 @@
 """
 import sys
 
-from fs import open_fs
+from fs import open_fs, path
 from PyQt5 import QtWidgets
-from fslib import fs_filedialog
+from fslib import ui_filepicker
 
-
-class FilePicker(QtWidgets.QMainWindow, fs_filedialog.Ui_MainWindow):
-    def __init__(self, parent=None, fs_name=u"~/", file_pattern=u'*.*'):
+class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
+    def __init__(self, parent=None, fs_name=u"~/", file_pattern=u'*.*', title=u'FS File Picker'):
         super(FilePicker, self).__init__(parent)
         self.setupUi(self)
         self.filename = None
-        self.setWindowTitle("FS File Picker")
+        self.setWindowTitle(title)
         self.fs_name = fs_name
         self.home_fs = None
         self.last_index = 0
@@ -73,13 +72,17 @@ class FilePicker(QtWidgets.QMainWindow, fs_filedialog.Ui_MainWindow):
         self.close()
 
 
-def filepicker(parent=None, fs_name=u'~/', file_pattern=u'*.*'):
-    app = QtWidgets.QApplication(sys.argv)
-    form = FilePicker(parent, fs_name, file_pattern)
+def fs_filepicker(parent=None, fs_name=u'~/', file_pattern=u'*.*', title=u'FS File Picker'):
+    if parent is None:
+        app = QtWidgets.QApplication(sys.argv)
+    form = FilePicker(parent, fs_name, file_pattern, title=title)
     form.show()
-    app.exec_()
-    return form.filename
+    if parent is None:
+        app.exec_()
+
+    fs_path = path.combine(form.fs_name, form.filename)
+    return fs_path
 
 if __name__ == '__main__':
-    print(filepicker())
+    print(fs_filepicker())
 
